{% extends 'madc/base.html' %}
{% load i18n %}
{% load humanize %}
{% load bootstrap %}

{% block view_block %}
<div class="card-body bg-primary rounded-top d-flex align-items-center">
    <h3 class="me-3">{% translate "Administration" %}</h3>
</div>
<div class="card-body rounded-bottom">
    {% include 'madc/partials/table/skill-list.html' %}
</div>
{% endblock %}

{% block extra_javascript %}
    {% include 'madc/bundles/settings-bundles.html' %}
    {% include 'madc/partials/modals/skilllist-delete.html' %}
    {% include 'madc/bundles/administration-bundles.html' %}

    {% include 'madc/partials/modals/modal.html' with name="ViewDoctrine" %}

    <script type="application/javascript">
        setupModal('#modalViewDoctrineContainer', 'ajax_doctrine', '#modalViewDoctrineContent', '#modalViewDoctrineLoader');
    </script>
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
